@@ -6,8 +6,13 @@ import pytz
 import redis
 from copy import deepcopy
 from typing import Callable
-from django.db import models as django_models
+
+from django.conf import settings
+from django.core import exceptions
+from django.db import models as django_models, IntegrityError
+from django.db.models.query import ModelIterable
 from django.db.models.signals import post_save, pre_delete
+from django.db.models.utils import resolve_callables
 from django.dispatch import receiver
 
 from .utils import check_types, check_classes, get_ids_from_untyped_data
@@ -743,7 +748,7 @@ class RedisRoot:
                     if redis_instance[field_name] != field_value:
                         fields_to_update[field_name] = field_value
             return fields_to_update
-        
+
         django_instance_model = django_instance.__class__
         old_redis_instance = self.get(django_instance_model, django_id=django_instance.id)
         redis_dict = self.django_instance_to_redis_params(
@@ -768,8 +773,8 @@ class RedisRoot:
             )
             if fields_to_update:
                 self.update(django_instance_model, old_redis_instance,
-                                  **fields_to_update
-                                  )
+                            **fields_to_update
+                            )
                 redis_instance = self.get(django_instance_model, django_id=django_instance.id)[0]
                 result_redis_instance_id = redis_instance['id']
             else:
@@ -1415,3 +1420,46 @@ class RedisModel:
             return meta[field_name]
         else:
             raise Exception(f'{name} has no field {field_name}')
+
+
+class RedisQuerySet:
+
+    def __init__(self, model=None, query=None):
+        self.model = model
+
+    def get(self, **filters):
+        return self.model.redis_root.get(self.model, **filters)
+
+    def update(self, instances, **params):
+        return self.model.redis_root.update(self.model, instances, **params)
+
+    def create(self, **params):
+        return self.model.save(**params)
+
+    def delete(self, instances):
+        return self.model.redis_root.delete(self.model, instances)
+
+
+class RedisObjectsManager(django_models.Manager):
+    def get_queryset(self, **kwargs):
+        return RedisQuerySet(self)
+
+
+class DjangoRedisModel(django_models.Model):
+    objects = RedisObjectsManager()
+    django_objects = django_models.Manager()
+    redis_root = settings.REDIS_ROOT
+
+    def save(self, *args, **kwargs):
+        existing_fields = {
+            field.name: getattr(self, field.name)
+            for field in self.__class__._meta.get_fields()  # Parents included
+            if field.name not in ['objects', 'django_objects', 'redis_root']
+        }
+        return self.redis_root.create(self.__class__, **existing_fields)
+
+    def django_save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
+
+    class Meta:
+        abstract = True
